# ---------------------------------------
# Maximising detection of species prescence
# ---------------------------------------

#replace *** with local directory

# -------------------------------
# Prepare data at 100m resolution
# -------------------------------

library(plyr); library(dplyr)

#read in the data
dat<-read.csv('***/Schori_et_al_2020_PLOSOne_dataset/maximising-detection-of-species-prescence/full-transect-dataset.csv',na.strings = "")

# make the NAs in the sex column a '0'
dat$Sex[is.na (dat$Sex)] <- 0

#create new column with 0 or 1 or represent when a grasshopper is present
dat$Present <- (dat$Sex != "NA")
dat$Present <- as.integer(as.logical(dat$Present))

# drop columns that aren't needed
dat <- dat %>%
  select("Present","Sex","Visit_All_time","Location","Transect","Season","Month","Ground","Barometric_pressure","Cloud_cover", "Standard_time")

#add time squared variable
dat$time_sq <- dat$Standard_time*dat$Standard_time

#make column with standardised ground temperature
dat$Ground <- as.numeric(as.character(dat$Ground))
dat$Ground_standard <- (dat$Ground - mean(dat$Ground, na.rm = T)) / sd(dat$Ground, na.rm = T)
dat$temp_sq <- dat$Ground_standard*dat$Ground_standard

#rename the transects so that snowy and patersons have different IDs
dat$TransectID <- paste(dat$Location, dat$Transect,sep="-")

#make the new column a factor rather than a character
dat$TransectID <- as.factor(dat$TransectID)

#rescale season so thats its on a better scale
dat$SeasonID <- dat$Season - 2015

#subset for unique rows of info
library(data.table)
dt <- data.table(dat)
dt1<-dt[,.SD[which.max(Present)],by=list(Transect, Location, Visit_All_time)]

#drop rows where temp and sky contain NA
dt1 <- dt1[dt1$Ground != 'NA',]
dt1 <- dt1[dt1$Cloud_cover != 'NA',]
dt1 <- droplevels(dt1)

#check for missing values
library(Amelia)
missmap(dt1, main = "Missing values vs observed")


# ----------------------------
# Logistic Regression Analysis
# ----------------------------

# read in data
dat <- read.csv('***/Schori_et_al_2020_PLOSOne_dataset/maximising-detection-of-species-prescence/full-transect-dataset-100m.csv')

dat$SeasonID <- as.factor(as.integer(dat$SeasonID))

dat$Location <- revalue(dat$Location, c("Pattersons"="Patersons Terrace", "Snowy"="Snowy River"))

#variables of interest: time, time_sq, location, transect ID (random!), sky/cloud cover, temperature, temperature_sq, season (random?)
# note that there is no temperature for the November data

#Explore the dataset

#run logistic regression
library(lme4)
library(lmerTest)

#Exclude temperature from the anaylsis because no data for November in the first year

#full model
mod1 <- glmer(Present ~ Location + Month + Cloud_cover + Ground_standard + (1|SeasonID) + (1|TransectID) ,  family = "binomial", data = dat)

#check for overdispersion
E1 <- residuals(mod1)
p1 <- length(fixef(mod1)) + 1
(overdisp1 <- sum(E1^2) /(nrow(dat) - p1))
#value has to be less than 1 (which it is)

#basic informative model
mod2 <- glmer(Present ~ Location + Month + Cloud_cover + (1|SeasonID) + (1|TransectID),  family = "binomial", data = dat)

#check for overdispersion
E1 <- residuals(mod2)
p1 <- length(fixef(mod2)) + 1
(overdisp1 <- sum(E1^2) /(nrow(dat) - p1))
#value has to be less than 1 (which it is)

mod3 <- glmer(Present ~ Location + Month + (1|SeasonID) + (1|TransectID),  family = "binomial", data = dat)

mod4 <- glmer(Present ~ Location + Cloud_cover + (1|SeasonID) + (1|TransectID),  family = "binomial", data = dat)

anova(mod4, mod2, test = "Chisq")
AIC(mod1, mod2, mod3, mod4)

#model 2 comes out on top. 

summary(mod2)

# --------------
# Plot the model
# --------------

#note: make sure the order of the months is alphabetical as it is specified in the model.
NewData <- expand.grid(Location = levels(dat$Location), 
                       Month = levels(dat$Month), 
                       Cloud_cover = levels(dat$Cloud_cover), 
                       SeasonID = c(0:20), 
                       TransectID = levels(dat$TransectID))

X <- model.matrix(~ Location + Month + Cloud_cover,
                  data = NewData)

NewData$eta         <- X %*% fixef(mod2)
NewData$Success <- exp(NewData$eta) / (1 + exp(NewData$eta))
head(NewData,15)

#Get the standard errors
NewData$Var <- diag(X %*% vcov(mod2) %*% t(X))
NewData$se  <- sqrt(NewData$Var)

NewData$seLow  <- exp(NewData$eta - 1.96 * NewData$se) / (1 + exp(NewData$eta - 1.96 * NewData$se))
NewData$seHigh <- exp(NewData$eta + 1.96 * NewData$se) / (1 + exp(NewData$eta + 1.96 * NewData$se))
head(NewData, 10)

#reorder the levels so that they plot correctly
NewData$Month2 <- factor(NewData$Month, levels = c("Nov", "Dec", "Jan", "Feb", "Mar"))
NewData$Cloud_cover2 <- factor(NewData$Cloud_cover, levels = c("no cloud", "high cloud", "patchy cloud", "overcast"))

dat100 <- NewData

library(ggplot2)

ggplot(data = NewData, aes(Month2, Success)) +
  geom_point() + #plot the points
  ylab("Probability detection (100m transect)") +
  theme_bw() + 
  geom_errorbar(aes(ymin=seLow, ymax=seHigh), width = 0.2) + 
  facet_grid(Location ~ Cloud_cover2) + 
  labs(x = "Month", y = (expression("Probability of detection over 100 "~m^2)))

# -------------
# post-hoc test
# -------------

library(multcompView)
library(lsmeans)

marginal <- lsmeans(mod2, ~Location + Month + Cloud_cover, adjust = "tukey")

(post_hoc_100 <- cld(marginal, 
                     alpha = 0.05,
                     Letters = letters,
                     adjust = "tukey"))


# ------------------------------
# Prepare data at 20m resolution
# ------------------------------

library(tidyverse)

#read in the data
dat<-read.csv('***/Schori_et_al_2020_PLOSOne_dataset/maximising-detection-of-species-prescence/full-transect-dataset.csv',na.strings = "")

#change the names of the factors
dat$Location <- revalue(dat$Location, c("Pattersons"="Patersons Terrace", "Snowy"="Snowy River"))

# drop columns that aren't needed
dat <- dat %>%
  select("Sex","Visit_All_time","Location","Transect","Season","Month","Ground","Barometric_pressure", "Cloud_cover", "Standard_time","X20mtransect")

#make X20mtransect a factor
dat$X20mtransect <- as.factor(as.integer(dat$X20mtransect))

#create a new dataset where there is data for each 20m searched. 

# create a new object with the different categories in it
skel <- data.frame(X20mtransect = seq(20, 100, 20))
skel$X20mtransect <- as.factor(skel$X20mtransect)

#form the new dataset by joining them together
dat1 <- dat %>%
  group_by_at(vars(Visit_All_time:Standard_time)) %>%
  nest() %>%
  mutate(data = map(data, ~full_join(.x, skel, by = "X20mtransect"))) %>%
  unnest() %>%
  replace_na(list(Present = 0))

# make the NAs in the sex column a '0'
dat1$Sex[is.na (dat1$Sex)] <- 0

#create new column with 0 or 1 or represent when a grasshopper is present
dat1$Present <- (dat1$Sex != "0")
dat1$Present <- as.integer(as.logical(dat1$Present))

#add time squared variable
dat1$time_sq <- dat1$Standard_time*dat1$Standard_time

#make column with standardised ground temperature
dat1$Ground <- as.numeric(as.character(dat1$Ground))
dat1$Ground_standard <- (dat1$Ground - mean(dat1$Ground, na.rm = T)) / sd(dat1$Ground, na.rm = T)
dat1$temp_sq <- dat1$Ground_standard*dat1$Ground_standard

#rename the transects so that snowy and patersons have different IDs
dat1$TransectID <- paste(dat1$Location, dat1$Transect,sep="-")

#make the new column a factor rather than a character
dat1$TransectID <- as.factor(dat1$TransectID)

#rescale season so thats its on a better scale
dat1$SeasonID <- dat1$Season - 2015

#subset for unique rows of info
library(data.table)
dt <- data.table(dat1)
dt1<-dt[,.SD[which.max(Present)],by=list(TransectID, Visit_All_time, X20mtransect)]

#drop rows where temp and sky contain NA
dt1 <- dt1[dt1$Ground != 'NA',]
dt1 <- dt1[dt1$Cloud_cover != 'NA',]
dt1 <- droplevels(dt1)

#check for missing values
library(Amelia)
missmap(dt1, main = "Missing values vs observed")

#drop excess levels from the dataframe
droplevels(dt1)

dat20 <- dt1

# -------------------------------
# Logistic regression on 20m data
# -------------------------------

#variables of interest: time, time_sq, location, transect ID (random!), sky/cloud cover, temperature, temperature_sq, season
# note that there is no temperature for the November data

#Explore the dataset

#create graph
library(lattice)
xyplot(Present ~ Standard_time | Location*Cloud_cover,
       data = dat20, pch = 16, col = 1,
       strip = function(bg = "white", ...)
         strip.default(bg = 'white', ...), 
       scales = list(alternating = TRUE, 
                     x = list(relation = "free"), 
                     y = list(relation = "same")), 
       xlab = list(label = "X", ex = 1.5), 
       ylab = list(label = "Y", cex = 1.5))

xyplot(Present ~ Location | Cloud_cover*Month,
       data = dat20, pch = 16, col = 1,
       strip = function(bg = "white", ...)
         strip.default(bg = 'white', ...), 
       scales = list(alternating = TRUE, 
                     x = list(relation = "free"), 
                     y = list(relation = "same")), 
       xlab = list(label = "X", ex = 1.5), 
       ylab = list(label = "Y", cex = 1.5))


#Look at the distribution of 0s and 1s
table(dat20$Present, dat20$Location, dat20$Month)

#run logistic regression
library(lme4)
library(lmerTest)

#full model
mod1 <- glmer(Present ~ Location + Month + Cloud_cover + Ground_standard + (1|SeasonID) + (1|TransectID) ,  family = "binomial", data = dat20)

#basic informative model
mod2 <- glmer(Present ~ Location + Month + Cloud_cover + (1|SeasonID) + (1|TransectID),  family = "binomial", data = dat20)

mod3 <- glmer(Present ~ Location + Month + (1|SeasonID) + (1|TransectID),  family = "binomial", data = dat20)

mod4 <- glmer(Present ~ Location + Cloud_cover + (1|SeasonID) + (1|TransectID),  family = "binomial", data = dat20)

anova(mod1, mod2, mod3, mod4)
AIC(mod1, mod2, mod3, mod4)

#model 2 comes out on top

#check for overdispersion
E1 <- residuals(mod2)
p1 <- length(fixef(mod2)) + 1
(overdisp1 <- sum(E1^2) /(nrow(dat20) - p1))

# value has to be less than 1 (there is evidence of overdispersion in this model)
# However, overdispersion not a big issue for binomial mixed effects model. 

summary(mod2)

# ------------
# Plot model 2
# ------------

#note: make sure the order of the months is alphabetical as it is specified in the model.
NewData <- expand.grid(Location = levels(dat20$Location), 
                       Month = levels(dat20$Month), 
                       Cloud_cover = levels(dat20$Cloud_cover), 
                       SeasonID = c(0:20), 
                       TransectID = levels(dat20$TransectID))

X <- model.matrix(~ Location + Month + Cloud_cover,
                  data = NewData)

NewData$eta         <- X %*% fixef(mod2)
NewData$Success <- exp(NewData$eta) / (1 + exp(NewData$eta))
head(NewData,15)

#Get the standard errors
NewData$Var <- diag(X %*% vcov(mod2) %*% t(X))
NewData$se  <- sqrt(NewData$Var)

NewData$seLow  <- exp(NewData$eta - 1.96 * NewData$se) / (1 + exp(NewData$eta - 1.96 * NewData$se))
NewData$seHigh <- exp(NewData$eta + 1.96 * NewData$se) / (1 + exp(NewData$eta + 1.96 * NewData$se))
head(NewData, 10)

#reorder the levels so that they plto correctly
NewData$Month2 <- factor(NewData$Month, levels = c("Nov", "Dec", "Jan", "Feb", "Mar"))
NewData$Cloud_cover2 <- factor(NewData$Cloud_cover, levels = c("no cloud", "high cloud", "patchy cloud", "overcast"))

#rename levels
levels(NewData$Location)[levels(NewData$Location == "Pattersons")] <- "Patersons Terrace"
levels(NewData$Location)[levels(NewData$Location == "Snowy")] <- "Snowy River"

dat20 <- NewData

library(ggplot2)

ggplot(data = NewData, aes(Month2, Success)) +
  geom_point() + #plot the points
  ylab("Probability detection (20m transect)") +
  theme_bw() + 
  geom_errorbar(aes(ymin=seLow, ymax=seHigh), width = 0.2) + 
  facet_grid(Location ~ Cloud_cover2) + 
  labs(x = "Month", y = (expression("Probability of detection over 20 "~m^2)))

# -------------
# post-hoc test
# --------------

marginal20 <- lsmeans(mod2, ~ Location + Month + Cloud_cover, adjust = "tukey")

(post_hoc_20 <- cld(marginal20, 
                    alpha = 0.05,
                    Letters = letters,
                    adjust = "tukey"))

# --------------------
# make combined graph
# --------------------

#join dat20 and dat100 together 

dat20$Distance <- c("20 m")
dat100$Distance <- c("100 m")

dat.all <- rbind(dat20,dat100)

#plot the graph

dodge <- position_dodge(width=0.5) 

ggplot(data = dat.all, aes(Month2, Success)) +
  geom_point(aes(shape=Distance),position=position_dodge(width = 0.2)) + #plot the points
  ylab("Probability detection") +
  theme_bw() + 
  geom_errorbar(aes(ymin=seLow, ymax=seHigh), position=position_dodge(width=0.2), width = 0.2) +
  facet_grid(Location ~ Cloud_cover2) + 
  labs(x = "Month", y = (expression("Probability of detection")))

# --------------------------------------------------
# Probability of detecting adult females grasshopper
# --------------------------------------------------

# -------------------------------------
# Prepare the data at a 100m resolution
# -------------------------------------

library(tidyverse)

#read in the data
dat<-read.csv('***/Schori_et_al_2020_PLOSOne_dataset/maximising-detection-of-species-prescence/full-transect-dataset.csv',na.strings = "")

#subset data to get only Nov and Dec
dat<-dat[dat$Month =='Nov' | dat$Month == 'Dec',]

#fix age variable to only have 3 levels
dat$Age[dat$Age == "J" | dat$Age == "nymph"] <- "j"
dat$Age[dat$Age == "no data"] <- NA
dat[dat == "no data"] <- NA
dat <- droplevels(dat)


#drop columns that aren't of interest
library(dplyr)
dat1 <- dat %>%
  mutate_all(as.factor) %>%
  select(Location, Season, Month, Visit_All_time, Ground, Cloud_cover, Standard_time, Transect, Sex, Body_length, Age, X20mtransect)

#create new column with 0 or 1 or represent when adult females present
dat1$Present <- (dat1$Sex == "female" & dat1$Age == "a")
dat1$Present <- as.integer(as.logical(dat1$Present))

#add time squared variable
dat1$Standard_time <- as.numeric(paste(dat1$Standard_time))
dat1$time_sq <- dat1$Standard_time*dat1$Standard_time

#make column with standardised ground temperature
dat1$Ground <- as.numeric(as.character(dat1$Ground))
dat1$Ground_standard <- (dat1$Ground - mean(dat1$Ground, na.rm = T)) / sd(dat1$Ground, na.rm = T)
dat1$temp_sq <- dat1$Ground_standard*dat1$Ground_standard

#rename the transects so that snowy and patersons have different IDs
dat1$TransectID <- paste(dat1$Location, dat1$Transect,sep="-")

#make the new column a factor rather than a character
dat1$TransectID <- as.factor(dat1$TransectID)

#rescale season so thats its on a better scale
dat1$Season <- as.numeric(paste(dat$Season))
dat1$SeasonID <- dat1$Season - 2015

#subset for unique rows of info
library(data.table)
dt <- data.table(dat1)
dt1<-dt[,.SD[which.max(Present)],by=list(TransectID, Visit_All_time)]

#drop rows where temp and sky contain NA
dt1 <- dt1[dt1$Ground != 'NA',]
dt1 <- dt1[dt1$Cloud_cover != 'NA',]
dt1 <- droplevels(dt1)

#check for missing values
library(Amelia)
missmap(dt1, main = "Missing values vs observed")

# ----------------------
# Detectability at 100 m
# ----------------------

#Look at the distribution of 0s and 1s
table(dt1$Present, dt1$Location)

dt1$TransectID <- as.factor(as.character(dt1$TransectID))

#run logistic regression
library(lme4)
library(lmerTest)

# modelling

mod2 <- glmer(Present ~ Location + Cloud_cover + (1|SeasonID) + (1|TransectID),  family = "binomial", data = dt1)

mod3 <- glmer(Present ~ Location + (1|SeasonID) + (1|TransectID),  family = "binomial", data = dt1)

mod4 <- glmer(Present ~ Cloud_cover  + (1|SeasonID) + (1|TransectID),  family = "binomial", data = dt1)

anova(mod2, mod3) 
anova(mod2,mod4)

AIC(mod2, mod3, mod4)

# models do not significantly differ, model 3 has lowest AIC

# check model fit

E1 <- residuals(mod3)
p1 <- length(fixef(mod3)) + 1
(overdisp1 <- sum(E1^2) /(nrow(dt1) - p1))

summary(mod3)

# ---------------
# Plot the model  
# ---------------

#note: make sure the order of the months is alphabetical as it is specified in the model.
NewData <- expand.grid(Location = levels(dt1$Location), 
                       SeasonID = c(0:20), 
                       Month = levels(dt1$Month),
                       TransectID = levels(dt1$TransectID))

head(NewData)                       

X <- model.matrix(~ Location,
                  data = NewData)

NewData$eta         <- X %*% fixef(mod3)
NewData$Success <- exp(NewData$eta) / (1 + exp(NewData$eta))
head(NewData,15)

#Get the standard errors
NewData$Var <- diag(X %*% vcov(mod3) %*% t(X))
NewData$se  <- sqrt(NewData$Var)

NewData$seLow  <- exp(NewData$eta - 1.96 * NewData$se) / (1 + exp(NewData$eta - 1.96 * NewData$se))
NewData$seHigh <- exp(NewData$eta + 1.96 * NewData$se) / (1 + exp(NewData$eta + 1.96 * NewData$se))
head(NewData, 10)

#reorder the levels so that they plot correctly
NewData$Month2 <- factor(NewData$Month, levels = c("Nov", "Dec", "Jan", "Feb", "Mar"))


dat100 <- NewData
dat100$Location <- revalue(dat100$Location, c("Pattersons"="Patersons Terrace", "Snowy"="Snowy River"))

# ------------------------------
# Prepare data at 20m resolution   
# ------------------------------

#read in the data
dat<-read.csv('***/Schori_et_al_2020_PLOSOne_dataset/maximising-detection-of-species-prescence/full-transect-dataset.csv',na.strings = "")

#change the names of the factors
dat$Location <- revalue(dat$Location, c("Pattersons"="Patersons Terrace", "Snowy"="Snowy River"))

# drop columns that aren't needed
dat <- dat %>%
  select(Sex,Age, Visit_All_time,Location,Transect,Season,Month,Ground,Barometric_pressure, Cloud_cover, Standard_time,X20mtransect)

#make X20mtransect a factor
dat$X20mtransect <- as.factor(as.integer(dat$X20mtransect))

#fix age variable to only have 3 levels
dat$Age[dat$Age == "J" | dat$Age == "nymph"] <- "j"
dat$Age[dat$Age == "no data"] <- NA
dat[dat == "no data"] <- NA
dat <- droplevels(dat)

#subset data to get only Nov and Dec
dat<-dat[dat$Month =='Nov' | dat$Month == 'Dec',]

#create new column with 0 or 1 or represent when adult females present
dat$Present <- (dat$Sex == "female" & dat$Age == "a")
dat$Present <- as.integer(as.logical(dat$Present))

#move X20mtransect column to the end of the dataframe
dat <- dat %>%
  select(-X20mtransect, everything())

#create a new dataset where there is data for each 20m searched. 

# create a new object with the different categories in it
skel <- data.frame(X20mtransect = seq(20, 100, 20))
skel$X20mtransect <- as.factor(skel$X20mtransect)

#form the new dataset by joining them together
dat1 <- dat %>%
  group_by_at(vars(Sex:Standard_time)) %>%
  nest() %>%
  mutate(data = map(data, ~full_join(.x, skel, by = "X20mtransect"))) %>%
  unnest() %>%
  replace_na(list(Present = 0))

#add time squared variable
dat1$Standard_time <- as.numeric(paste(dat1$Standard_time))
dat1$time_sq <- dat1$Standard_time*dat1$Standard_time

#make column with standardised ground temperature
dat1$Ground <- as.numeric(as.character(dat1$Ground))
dat1$Ground_standard <- (dat1$Ground - mean(dat1$Ground, na.rm = T)) / sd(dat1$Ground, na.rm = T)
dat1$temp_sq <- dat1$Ground_standard*dat1$Ground_standard

#rename the transects so that snowy and patersons have different IDs
dat1$TransectID <- paste(dat1$Location, dat1$Transect,sep="-")

#make the new column a factor rather than a character
dat1$TransectID <- as.factor(dat1$TransectID)

#rescale season so thats its on a better scale
dat1$Season <- as.numeric(paste(dat1$Season))
dat1$SeasonID <- dat1$Season - 2015

#subset for unique rows of info
library(data.table)
dt <- data.table(dat1)
dt1<-dt[,.SD[which.max(Present)],by=list(TransectID, Visit_All_time)]

#drop rows where temp and sky contain NA
dt1 <- dt1[dt1$Ground != 'NA',]
dt1 <- dt1[dt1$Cloud_cover != 'NA',]
dt1 <- droplevels(dt1)

#check for missing values
library(Amelia)
missmap(dt1, main = "Missing values vs observed")

#make transectID include the distance too
dt1$TransectID <- paste(dt1$X20mtransect, dt1$TransectID,sep="-")

# -------------------------------
# Logistic regression on 20m data  
# -------------------------------

dt1 <- droplevels(dt1)

#Look at the distribution of 0s and 1s
table(dt1$Present, dt1$Location)

#run logistic regression
library(lme4)
library(lmerTest)

#full model

#including "Season ID" in the model gives a singular fit so exluded from the following models

#basic informative model
mod2 <- glmer(Present ~ Location + Month + Cloud_cover + (1|TransectID),  family = "binomial", data = dt1)

mod3 <- glmer(Present ~ Location + Month + (1|TransectID),  family = "binomial", data = dt1)

mod4 <- glmer(Present ~ Location  + (1|TransectID),  family = "binomial", data = dt1)

anova(mod2, mod3)
anova(mod3, mod4)

AIC (mod2, mod3, mod4)

# models do not signifincalty differ, mod4 has lowest AIC

# check model fit

E1 <- residuals(mod4)
p1 <- length(fixef(mod4)) + 1
(overdisp1 <- sum(E1^2) /(nrow(dt1) - p1))

summary(mod4)

# --------------
# Plot the model 
# --------------

str(dt1)

#maketransect ID a factor
dt1$TransectID <- as.factor(dt1$TransectID)

#make transectID include the distance too
#dt1$TransectID <- paste(dt1$X20mtransect, dt1$TransectID,sep="-")

#note: make sure the order of the months is alphabetical as it is specified in the model.
NewData <- expand.grid(Location = levels(dt1$Location),
                       SeasonID = c(0:20),
                       Month = levels(dt1$Month),
                       TransectID = levels(dt1$TransectID))

head(NewData)                       

X <- model.matrix(~ Location,
                  data = NewData)

NewData$eta         <- X %*% fixef(mod4)
NewData$Success <- exp(NewData$eta) / (1 + exp(NewData$eta))
head(NewData,15)

#Get the standard errors
NewData$Var <- diag(X %*% vcov(mod4) %*% t(X))
NewData$se  <- sqrt(NewData$Var)

NewData$seLow  <- exp(NewData$eta - 1.96 * NewData$se) / (1 + exp(NewData$eta - 1.96 * NewData$se))
NewData$seHigh <- exp(NewData$eta + 1.96 * NewData$se) / (1 + exp(NewData$eta + 1.96 * NewData$se))
head(NewData, 10)

#reorder the levels so that they plto correctly
NewData$Month2 <- factor(NewData$Month, levels = c("Nov", "Dec", "Jan", "Feb", "Mar"))

dat20 <- data.frame(NewData, stringsAsFactors=F)

# ------------------------------------
# Graph the findings for adult females
# ------------------------------------

#join dat20 and dat100 together 

dat20$Area <- c("20 m x 1 m")
dat100$Area <- c("100 m x 1 m")

dat20 <- data.frame(dat20, stringsAsFactors=F)
dat100 <- data.frame(dat100, stringsAsFactors=F)

#drop the transect ID columns
dat20$TransectID <- NULL
dat20$Area <- as.factor(dat20$Area)
dat20 <- droplevels(dat20)

str(dat20)

dat100$TransectID <- NULL
dat100$Area <- as.factor(dat100$Area)
dat100 <- droplevels(dat100)

dat.all <- rbind(do.call(data.frame,dat100), do.call(data.frame, dat20))

#plot the graph ----

dodge <- position_dodge(width=0.5) 

library(ggplot2) 


ggplot(data = dat.all, aes(Area, Success, shape=Location)) +
  geom_point(aes(shape=Location), size = 2, position=position_dodge(width = 0.6)) + #plot the points
  geom_errorbar(aes(ymin=seLow, ymax=seHigh), width = 0.3, position=position_dodge(width=0.6)) +
  # facet_wrap(~Area) + 
  theme(axis.text.x = element_text(face = "plain", color = "black", 
                                   size = 12)) +
  theme_bw() +
  labs(x = "Transect area", y = (expression("Probability of detection")))

