# -----------------------------------------------------
# transects versus plot searches
# ------------------------------------------------------

#replace *** with local directory

# ----------------
# FULL POPULATION 
# ----------------

# read in the data
dat <- read.csv("***/Schori_et_al_2020_PLOSOne_dataset/transect-versus-plot/Density_full_popn_Patersons_Transect_v_Plot.csv")

# clean the data
dat$Search_type <- as.factor(dat$Search_type)
dat$Season <- as.factor(dat$Season)
dat$Name <- as.factor(dat$Name)

# Modelling

library(lme4)
library(lmerTest)

# POISSON MODEL ----

mod <- glm(count ~ Search_type + Month*Season, family = poisson, data = dat)

# check model fit

#check for normal distribution of residuals
hist(residuals(mod),col="darkgray")

#check for homoscedastic residulas
plot(fitted(mod),residuals(mod))

#If p> 0.05, then model fit is good.
1 - pchisq(summary(mod)$deviance, summary(mod)$df.residual)

#look at the critical level of dispersion by comparing to the degrees of freedom
qchisq(0.95, df.residual(mod))

#get model deviance
deviance(mod)

#get pearson's chi2
pr <- residuals(mod,"pearson")
sum(pr^2) #if values are lower than critical value, then model fit is good. 

#this model is not a good fit and the data are over dispersed. 

# QUASI POISSON MODEL ---- 

mod.q <- glm(count ~ Search_type + Month*Season, family = quasipoisson, data = dat)

# check model fit

#check for normal distribution of residuals
hist(residuals(mod.q),col="darkgray")

#check for homoscedastic residulas
plot(fitted(mod.q),residuals(mod.q))

#If p> 0.05, then model fit is good.
1 - pchisq(summary(mod.q)$deviance, summary(mod.q)$df.residual)

#look at the critical level of dispersion by comparing to the degrees of freedom
qchisq(0.95, df.residual(mod.q))

#get model deviance
deviance(mod.q)

#get pearson's chi2
pr <- residuals(mod.q,"pearson")
sum(pr^2)#if values are lower than critical value, then model fit is good. 

#this model is still not a good fit and the data are over-dispersed. 

# NEGATIVE BINOMIAL MODEL ----

library(MASS)

mod.nb <- glm.nb(count ~ Search_type + Month + Season, data = dat)

#check for normal distribution of residuals
hist(residuals(mod.nb),col="darkgray")

#check for homoscedastic residuals
plot(fitted(mod.nb),residuals(mod.nb))

#If p> 0.05, then model fit is good.
1 - pchisq(summary(mod.nb)$deviance, summary(mod.nb)$df.residual)

#look at the critical level of dispersion by comparing to the degrees of freedom
qchisq(0.95, df.residual(mod.nb))

#get model deviance
deviance(mod.nb)

#get pearson's chi2
pr <- residuals(mod.nb,"pearson")
sum(pr^2)

# if values are lower than critical value, then model fit is good. 

# Pearson's is lower than critical, but the other tests of fit still aren't that great. 
# Using an interaction model between month and season does not fit the data well, even though it has a lower AIC value (not much of a difference though). 

# The best fitting model with reasonable low AIC is a negative binomial model with no interaction and all the variables included. 

summary(mod.nb)

# ------------------------
# predict the means values
# ------------------------

library(dplyr)

#make new dataset
nd <- expand.grid(Search_type = levels(dat$Search_type),
                  Month = levels(dat$Month), 
                  Season = levels(dat$Season))

#print out the means
cbind(nd, 
      Mean = predict(mod.nb, newdata=nd, type="response"), 
      SE = predict(mod.nb, newdata=nd, type="response", se.fit=T)$se.fit
)


newY <- predict(mod.nb, newdata = nd, type = "link", se.fit = TRUE)

pd <- data.frame(nd, count = newY)
pd <- mutate(pd, count=exp(count.fit))
pd <- mutate(pd, ucl=exp(count.fit + 1.96*count.se.fit))
pd <- mutate(pd, lcl=exp(count.fit - 1.96*count.se.fit))


# Graph the output

library(ggplot2)

levels(pd$Season) <- c("Season 1 (2015-16)", "Season 2 (2016-17)", "Season 3 (2017-18)")

#reorder the months
pd$Month <- factor(pd$Month, levels=c("Nov", "Dec", "Jan", "Feb", "Mar"))

ggplot(pd, aes(x = Month, y = count, ymax=ucl, ymin=lcl, shape = Search_type)) + 
  geom_point(position=position_dodge(width=0.6), size = 2) +
  geom_errorbar(position=position_dodge(width=0.6))+
  theme_bw() + 
  facet_wrap(~ Season) + 
  labs(x = "Month", y = expression ("Count per 300"~m^2))

# ------------
# ADULT FEMALE
# ------------

# read in the data
af <- read.csv("***/Schori_et_al_2020_PLOSOne_dataset/transect-versus-plot/Density_adult_female_plot_v_transect_patersons.csv")

library(dplyr)
str(af)
af <- af %>%
  filter(Month == "Nov" | Month == "Dec")

af$Search_type <- as.factor(as.character(af$Search_type))
af$Season <- as.factor(as.character(af$Season))
af <- droplevels(af)

# POISSON MODEL ----

library(lme4)
library(lmerTest)

#first model
mod <- glm(count ~ Search_type + Month + Season, data = af, family = poisson)

# check significance of month and season variables

mod2 <- glm(count ~ Search_type + Month, data = af, family = poisson)

mod3 <- glm(count ~ Search_type + Season, data = af, family = poisson)

mod4 <- glm(count ~ Search_type, data = af, family = poisson)

anova(mod, mod2, test = "Chisq")
anova(mod, mod3, test = "Chisq")
anova(mod, mod4, test = "Chisq")

AIC(mod, mod2, mod3, mod4)

# mod and mod2 do not significantly differ, but mod has slighly lower AIC

#check fit of mod

#do a goodness of fit test 
1 - pchisq(summary(mod)$deviance,summary(mod)$df.residual)
#the model fits the data well because p> 0.05

#look at the critical level of dispersion by comparing to the degrees of freedom
qchisq(0.95, df.residual(mod))

#get model deviance
deviance(mod)

#get pearson's chi2
pr <- residuals(mod,"pearson")
sum(pr^2) #if values are lower than critical value, then model fit is good.

plot(fitted(mod), residuals(mod))

#this model fits the data well, evidence of overdispersion because deviance>df, but only slightly, and all tests show that not significant. 

summary(mod)

# ------------------------
# predict the mean values
# ------------------------

#make new dataset
nd <- expand.grid(Search_type = levels(af$Search_type),
                  Month = levels(af$Month),
                  Season = levels(af$Season))

#print out the means
cbind(nd, 
      Mean = predict(mod, newdata=nd, type="response"), 
      SE = predict(mod, newdata=nd, type="response", se.fit=T)$se.fit
)


newY <- predict(mod, newdata = nd, type = "link", se.fit = TRUE)

pd <- data.frame(nd, count = newY)
pd <- mutate(pd, count=exp(count.fit))
pd <- mutate(pd, ucl=exp(count.fit + 1.96*count.se.fit))
pd <- mutate(pd, lcl=exp(count.fit - 1.96*count.se.fit))

# Graph the output

library(ggplot2)

levels(pd$Season) <- c("Season 1 (2015-16)", "Season 2 (2016-17)", "Season 3 (2017-18)")

#reorder the months
pd$Month <- factor(pd$Month, levels=c("Nov", "Dec"))

ggplot(pd, aes(x = Month, y = count, ymax=ucl, ymin=lcl, shape = Search_type)) + 
  geom_point(position=position_dodge(width=0.6), size = 2) +
  geom_errorbar(position=position_dodge(width=0.6))+
  theme_bw() + 
  facet_wrap(~ Season) + 
  labs(x = "Month", y = expression ("Count per 300"~m^2))

